@@ -1,49 +1,45 @@
-use strict;
-use warnings;
 package Plack::App::DAIA::Test;
 {
-  $Plack::App::DAIA::Test::VERSION = '0.45_1';
+  $Plack::App::DAIA::Test::VERSION = '0.41';
 }
 #ABSTRACT: Test DAIA Servers
 
-use base 'Test::Builder::Module';
-our @EXPORT = qw(test_daia_psgi test_daia daia_app);
-
 use URI::Escape;
 use Test::More;
 use Plack::Test;
 use Plack::App::DAIA;
 use Scalar::Util qw(reftype blessed);
 use HTTP::Request::Common;
-use Test::JSON::Entails;
+
+use base qw(Exporter Test::Builder::Module);
+our @EXPORT = qw(test_daia_psgi test_daia daia_app if_daia_call);
+
+my $CLASS = __PACKAGE__;
 
 sub test_daia {
     my $app = daia_app(shift) || do {
-        __PACKAGE__->builder->ok(0,"Could not construct DAIA application");
+        $CLASS->builder->ok(0,"Could not construct DAIA application");
         return;
     };
-    my $test_name = "test_daia";
-    $test_name = pop(@_) if @_ % 2;
     while (@_) {
         my $id = shift;
-        my $expected = shift;
+        my $code = shift;
         my $res = $app->retrieve($id);
-        if (!_if_daia_check( $res, $expected, $test_name )) {
+        if (!if_daia_call( $res, $code )) {
             $@ = "The thing isa DAIA::Response" unless $@;
-            __PACKAGE__->builder->ok(0, $@);
+            $CLASS->builder->ok(0, $@);
         }
     }
 }
 
 sub test_daia_psgi {
-    my $app = shift;
-
-    # TODO: load psgi file if string given and allow for URL
-    my $test_name = "test_daia";
-    $test_name = pop(@_) if @_ % 2;
+    my $app = daia_app(shift) || do {
+        $CLASS->builder->ok(0,"Could not construct DAIA application");
+        return;
+    };
     while (@_) {
         my $id = shift;
-        my $expected = shift;
+        my $code = shift;
         test_psgi $app, sub {
             my $req = shift->(GET "/?id=".uri_escape($id));
             my $res = eval { DAIA::parse( $req->content ); };
@@ -52,9 +48,9 @@ sub test_daia_psgi {
                 $@ =~ s/ at .* line.*//g;
                 $@ =~ s/\s*$//sg;
             }
-            if (!_if_daia_check( $res, $expected, $test_name )) {
+            if (!if_daia_call( $res, $code )) {
                 $@ = "No valid The thing isa DAIA::Response" unless $@;
-                __PACKAGE__->builder->ok(0, $@);
+                $CLASS->builder->ok(0, $@);
             }
         };
     }
@@ -88,18 +84,11 @@ sub daia_app {
     return;
 }
 
-# Call C<$code> with C<$daia> and set as C<$_>, if C<$daia> is a L<DAIA::Response>
-# and return C<$daia> on success. Return C<undef> otherwise.
-sub _if_daia_check {
-    my ($daia, $expected, $test_name) = @_;
+sub if_daia_call {
+    my ($daia, $code) = @_;
     if ( blessed($daia) and $daia->isa('DAIA::Response') ) {
-        if ( (reftype($expected)||'') eq 'CODE') {
-            local $_ = $daia;
-            $expected->($daia);
-        } else {
-            local $Test::Builder::Level = $Test::Builder::Level + 2;
-            entails $daia->json, $expected, $test_name;
-        }
+        local $_ = $daia;
+        $code->($daia);
         return $daia;
     }
 }
@@ -116,7 +105,7 @@ Plack::App::DAIA::Test - Test DAIA Servers
 
 =head1 VERSION
 
-version 0.45_1
+version 0.41
 
 =head1 SYNOPSIS
 
@@ -143,7 +132,7 @@ version 0.45_1
 
     # same usage, shown here with an inline server
 
-    test_daia_psgi
+    test_daia_psgi 
         sub {
             my $id = shift;
             my $daia = DAIA::Response->new();
@@ -159,8 +148,8 @@ version 0.45_1
 
 =head1 DESCRIPTION
 
-I<This model is experimental, so take care!> The current version has different
-behaviour for C<test_daia> and C<test_daia_psgi>, that might get fixed.
+This model is experimental, so take care! The current version has different
+behaviour for C<test_daia> and C<test_daia_psgi>.
 
 This module exports two methods for testing L<DAIA> servers. You must provide a
 DAIA server as code reference or as instance of L<Plack::App::DAIA> and a list
@@ -182,12 +171,12 @@ identifiers, each given a test function.
 =head2 daia_app ( $plack_app_daia | $url | $code )
 
 Returns an instance of L<Plack::App::DAIA> or undef. Code references or URLs
-are wrapped. For wrapped URLs C<$@> is set on failure. This method may be removed
-to be used internally only!
+are wrapped. For wrapped URLs C<$@> is set on failure.
 
-=head1 SEE ALSO
+=head2 if_daia_call ( $daia, $code )
 
-L<Plack::App::DAIA::Test::Suite> and L<provedaia>.
+Call C<$code> with C<$daia> and set as C<$_>, if C<$daia> is a L<DAIA::Response>
+and return C<$daia> on success. Return C<undef> otherwise.
 
 =head1 AUTHOR
 
@@ -195,7 +184,7 @@ Jakob Voss
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Jakob Voss.
+This software is copyright (c) 2011 by Jakob Voss.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
